#[repr(C)]pub struct miracle_plugin_animation_frame_data_t {
pub type_: u32,
pub runtime_seconds: f32,
pub duration_seconds: f32,
pub origin: [f32; 4],
pub destination: [f32; 4],
pub opacity_start: f32,
pub opacity_end: f32,
}Fields
type_: u32Animation type.
This one of #miracle_animation_type.
runtime_seconds: f32The runtime of the animation frame in seconds.
duration_seconds: f32The total duration of the animation in seconds.
origin: [f32; 4]The origin area, packed with x, y, w, and h.
destination: [f32; 4]The destination area, packed with x, y, w, and h.
opacity_start: f32The opacity start of the animation.
opacity_end: f32The opacity end of the animation.