#[repr(C)]pub struct miracle_workspace_t {
pub is_set: i32,
pub has_number: i32,
pub number: u32,
pub has_name: i32,
pub num_trees: u32,
pub internal: u64,
pub position: miracle_point_t,
pub size: miracle_size_t,
}Expand description
Describes a workspace.
Fields
is_set: i32If TRUE, the workspace is valid.
This may be FALSE for shell components that are not tethered to a particular
workspace.
has_number: i32If TRUE, #number is set.
number: u32The number of the workspace.
Only valid if #has_number is TRUE.
has_name: i32If TRUE, #name is set.
num_trees: u32The number of container trees in this workspace.
Use #miracle_plugin_get_workspace_tree to get the tree at a particular index. Each tree is represented by a #miracle_container_t which is the root of the tree.
internal: u64Pointer to internal data.
Please do not use unless you plan to be very sneaky.
position: miracle_point_tThe position of the workspace area.
size: miracle_size_tThe size of the workspace area.