pub type MirPlacementHints = c_uint;Expand description
Positioning hints for aligning a window relative to a rectangle.
These hints determine how the window should be positioned in the case that the surface would fall off-screen if placed in its ideal position.
For example, \p mir_placement_hints_flip_x will invert the x component of \p aux_rect_placement_offset and replace \p mir_placement_gravity_northwest with \p mir_placement_gravity_northeast and vice versa if the window extends beyond the left or right edges of the monitor.
If \p mir_placement_hints_slide_x is set, the window can be shifted horizontally to fit on-screen.
If \p mir_placement_hints_resize_x is set, the window can be shrunken horizontally to fit.
If \p mir_placement_hints_antipodes is set then the rect gravity may be substituted with the opposite corner (e.g. \p mir_placement_gravity_northeast to \p mir_placement_gravity_southwest) in combination with other options.
When multiple flags are set, flipping should take precedence over sliding, which should take precedence over resizing.