pub struct Container {
pub container_type: ContainerType,
pub is_floating: bool,
pub layout_scheme: LayoutScheme,
pub num_children: u32,
/* private fields */
}Fields
container_type: ContainerTypeThe type of the container.
is_floating: boolWhether the container is floating within its workspace.
layout_scheme: LayoutSchemeHow the container is laying out its content.
num_children: u32The number of child containers.
Implementations
Sourceimpl Container
impl Container
pub fn id(&self) -> u64
Sourcepub fn child_at(&self, index: u32) -> Option<Container>
pub fn child_at(&self, index: u32) -> Option<Container>
Get a child container from the parent container by index.
Returns None if the index is out of bounds or if the container
is not of type Parent.
Sourcepub fn get_children(&self) -> Vec<Container>
pub fn get_children(&self) -> Vec<Container>
Get all children from a parent container.
Returns an empty vector if the container is not of type Parent.
Sourcepub fn window(&self) -> Option<WindowInfo>
pub fn window(&self) -> Option<WindowInfo>
Get the window info from a window container.
Returns None if the container is not of type Window.