Functions
- miracle_
container_ ⚠get_ child_ at - Retrieve a child container from a parent container by index.
- miracle_
container_ ⚠get_ window - Retrieve the window info from a window container.
- miracle_
get_ ⚠active_ workspace - Retrieve the currently active workspace on the focused output.
- miracle_
get_ ⚠managed_ window_ at - Retrieve a managed window by index. Returns 0 on success, non-zero on failure.
- miracle_
get_ ⚠output_ at - Retrieve an output by index.
- miracle_
get_ ⚠plugin_ userdata - Retrieve the JSON-encoded userdata configured for this plugin.
- miracle_
num_ ⚠managed_ windows - Retrieve the number of windows managed by the given plugin handle.
- miracle_
num_ ⚠outputs - Retrieve the number of outputs.
- miracle_
output_ ⚠get_ workspace - Retrieve the workspace on the output by index.
- miracle_
queue_ ⚠custom_ animation - Queue a custom per-frame animation.
- miracle_
request_ ⚠workspace - Request a workspace by optional number and/or name.
- miracle_
window_ ⚠info_ get_ application - Retrieve the application info for a given window. Returns the internal ID on success, or -1 if the buffer is too small.
- miracle_
window_ ⚠info_ get_ workspace - Retrieve the workspace that a window is on.
- miracle_
window_ ⚠request_ focus - Request keyboard focus on a managed window. Returns 0 on success, -1 on error.
- miracle_
window_ ⚠set_ alpha - Set the alpha (opacity) of a managed window.
alpha_ptris a WASM linear memory offset pointing to a single f32 value. Returns 0 on success, -1 on error. - miracle_
window_ ⚠set_ rectangle - Set the position and size of a managed window. Returns 0 on success, -1 on error.
- miracle_
window_ ⚠set_ state - Set the state of a managed window. Returns 0 on success, -1 on error.
- miracle_
window_ ⚠set_ transform - Set the 4x4 column-major transform matrix of a managed window.
transform_ptris a WASM linear memory offset pointing to 16 contiguous f32 values. Returns 0 on success, -1 on error. - miracle_
window_ ⚠set_ workspace - Move a managed window to a different workspace. Returns 0 on success, -1 on error.
- miracle_
workspace_ ⚠get_ output - Retrieve the output that a workspace is on.
- miracle_
workspace_ ⚠get_ tree - Retrieve a tree from a workspace by index.