#[repr(u32)]pub enum TouchAxis {
X = 0,
Y = 1,
Pressure = 2,
TouchMajor = 3,
TouchMinor = 4,
Size = 5,
}Expand description
Touch axis identifier.
Variants
X = 0
X coordinate of the touch.
Y = 1
Y coordinate of the touch.
Pressure = 2
Pressure of the touch.
TouchMajor = 3
Length of the major axis of the touch ellipse.
TouchMinor = 4
Length of the minor axis of the touch ellipse.
Size = 5
Diameter of a circle centered on the touch point.