pub struct Output {
pub position: Point,
pub size: Size,
pub name: String,
pub is_primary: bool,
pub num_workspaces: u32,
/* private fields */
}Fields
position: PointThe position of the output.
size: SizeThe size of the output.
name: StringThe name of the output.
is_primary: boolWhether this is the primary output.
num_workspaces: u32The number of workspaces on this output.
Implementations
Sourceimpl Output
impl Output
pub fn id(&self) -> u64
Sourcepub fn from_c_with_name(value: &miracle_output_t, name: String) -> Self
pub fn from_c_with_name(value: &miracle_output_t, name: String) -> Self
Create from the C struct and a name string.
The name is passed separately because the C struct doesn’t contain the name directly (it’s written to a separate buffer by the host).
pub fn workspaces(&self) -> Vec<Workspace>
pub fn workspace(&self, index: u32) -> Option<Workspace>