Module plugin

Module plugin 

Traits

Plugin

Functions

get_active_workspace
Get the currently active workspace on the focused output.
get_output_at
Get an output by index.
get_outputs
Get all outputs.
get_userdata_json
Retrieve the raw JSON string of userdata configured for this plugin in the YAML config.
managed_windows
Lists the windows that are managed by this plugin.
num_outputs
Get the number of outputs.
queue_custom_animation
Queue a custom per-frame animation with a callback.
request_workspace
Request a workspace by optional number and/or name.