get_active_workspace

Function get_active_workspace 

pub fn get_active_workspace() -> Option<Workspace>
Get the currently active workspace on the focused output.

Returns None if there is no focused output or no active workspace.