managed_windows

Function managed_windows 

pub fn managed_windows() -> Vec<PluginWindow>
Lists the windows that are managed by this plugin.

A window that is managed by this plugin had to have been placed via a freestyle placement strategy, otherwise the tiling manager or the system is handling it independently.

Each returned PluginWindow wraps a WindowInfo (accessible via Deref) and additionally exposes setter methods for mutating the window’s state, workspace, size, transform, and alpha.