request_workspace

Function request_workspace 

pub fn request_workspace(
    number: Option<u32>,
    name: Option<&str>,
    focus: bool,
) -> Option<Workspace>
Request a workspace by optional number and/or name.

If a workspace with the given number or name already exists, it is returned. Otherwise, a new workspace is created on the focused output.

If focus is true, the workspace will be focused after creation/lookup.

Returns None if the workspace could not be created.