PluginWindow

Struct PluginWindow 

pub struct PluginWindow { /* private fields */ }
A handle to a window managed by this plugin, with mutation methods.

Returned by [crate::plugin::Plugin::managed_windows]. Wraps WindowInfo and exposes all of its read-only fields via std::ops::Deref, while adding setter methods that call into the compositor host.

Implementations

Source

impl PluginWindow

pub fn from_window_info(info: WindowInfo) -> Self

pub fn set_state(&self, state: WindowState) -> Result<(), ()>

Set the state of this window.

pub fn set_workspace(&self, workspace: &Workspace) -> Result<(), ()>

Move this window to a different workspace.

pub fn set_rectangle(&self, rect: Rectangle, animate: bool) -> Result<(), ()>

Set the position and size of this window.

pub fn set_transform(&self, transform: Mat4) -> Result<(), ()>

Set the 4x4 column-major transform matrix of this window.

pub fn set_alpha(&self, alpha: f32) -> Result<(), ()>

Set the alpha (opacity) of this window.

pub fn request_focus(&self) -> Result<(), ()>

Request keyboard focus on this window.

Methods from Deref<Target = WindowInfo>

pub fn id(&self) -> u64

Retrieve the ID of this window.

Plugins may elect to keep a reference to this ID so that they can match it with WindowInfo later.

pub fn application(&self) -> Option<ApplicationInfo>

Get the application that owns this window.

pub fn workspace(&self) -> Option<Workspace>

Get the workspace that this window is on.