WindowInfo

Struct WindowInfo 

pub struct WindowInfo {
    pub window_type: WindowType,
    pub state: WindowState,
    pub top_left: Point,
    pub size: Size,
    pub depth_layer: DepthLayer,
    pub name: String,
    pub transform: Mat4,
    pub alpha: f32,
    /* private fields */
}

Fields

window_type: WindowType

The type of this window.

state: WindowState

The state of the window.

top_left: Point

The position of the window.

size: Size

The size of the window.

depth_layer: DepthLayer

The depth layer of the window.

name: String

The name of the window.

transform: Mat4

The 4x4 transform matrix of the window (column-major).

alpha: f32

The alpha (opacity) of the window.

Implementations

Source

impl WindowInfo

pub unsafe fn from_c_with_name( value: &miracle_window_info_t, name: String, ) -> Self

Create from the C struct.

Safety

The title pointer must be valid and null-terminated.

pub fn id(&self) -> u64

Retrieve the ID of this window.

Plugins may elect to keep a reference to this ID so that they can match it with WindowInfo later.

pub fn application(&self) -> Option<ApplicationInfo>

Get the application that owns this window.

pub fn workspace(&self) -> Option<Workspace>

Get the workspace that this window is on.