#[repr(C)]pub struct miracle_container_t {
pub type_: u32,
pub is_floating: i32,
pub layout_scheme: u32,
pub num_child_containers: u32,
pub internal: u64,
}Expand description
Describes a container in a tree.
A container may either a parent or a window. Parent containers have children, which can be retrieved via #miracle_plugin_get_child_from_container.
The window of a window container can be retrieved via #miracle_plugin_get_window_info_from_container.
Fields
type_: u32The type of the container.
This is a #miracle_container_type.
is_floating: i32If TRUE, the container is floating within its workspace.
This is only set if #type is #miracle_container_type_parent.
layout_scheme: u32Describes how a container is laying out its content.
This is #miracle_layut_scheme.
This is only set if #type is #miracle_container_type_parent.
num_child_containers: u32The number of child containers inside of this container.
Use #miracle_plugin_get_child_from_container to query the container by index.
internal: u64Pointer to internal data.
Please do not use unless you plan to be very sneaky!